@@ -2,12 +2,15 @@
 # test various blockgroup profile combinations, use loop devices as block
 # devices
 
-source "$TEST_TOP/common"
+source "$TEST_TOP/common" || exit
 
 check_prereq mkfs.btrfs
 check_prereq btrfs
 
 setup_root_helper
+setup_loopdevs 4
+prepare_loopdevs
+dev1=${loopdevs[1]}
 
 test_get_info()
 {
@@ -21,6 +24,7 @@ test_get_info()
 	# device RAID0 as the same.
 	# Thus kernel may create new SINGLE chunks, causing extra warning
 	# when testing single device RAID0.
+	cond_wait_for_loopdevs
 	run_check $SUDO_HELPER mount -o ro "$dev1" "$TEST_MNT"
 	run_check_stdout "$TOP/btrfs" filesystem df "$TEST_MNT" > "$tmp_out"
 	if grep -q "Multiple block group profiles detected" "$tmp_out"; then
@@ -51,10 +55,6 @@ test_mkfs_multi()
 	test_get_info
 }
 
-setup_loopdevs 4
-prepare_loopdevs
-dev1=${loopdevs[1]}
-
 test_mkfs_single
 test_mkfs_single  -d  single  -m  single
 test_mkfs_single  -d  single  -m  single  --mixed
